const { ethers } = require("hardhat");
const tokenABI = require("../abi/token.json");
const portalABI = require("../abi/portal.json");

async function bridge(users, portalAddr, tokenAddr) {
    const provider = ethers.provider;
    const portalContract = new ethers.Contract(portalAddr, portalABI, provider);
    const tokenContract = new ethers.Contract(tokenAddr, tokenABI, provider);

    for (let i = 0; i < users.length; i++) {
        const privateKey = users[i]["private"];
        const user = users[i]["address"];
        const value = ethers.parseEther(users[i]["amount"])
        const signer = new ethers.Wallet(privateKey, provider);
        const contractWithSigner = portalContract.connect(signer);
        const usdxWithSigner = tokenContract.connect(signer);

        const approve = await usdxWithSigner.approve(portalAddr, value);
        await approve.wait();
        console.log("approve token to portal contract tx hash:", approve.hash);

        const deposit = await contractWithSigner.depositERC20Transaction(user, value, value, 0, false, "");
        await deposit.wait();
        console.log("deposit tx hash:", deposit.hash, " for user:", user);
    }
}

async function main() {
    const users = require("../account.json")
    const portalAddr = "";
    const usdxTokenAddr = ""

    await bridge(users, portalAddr, usdxTokenAddr);
}

main()
    .then(() => process.exit(0))
    .catch(error => {
        console.error(error);
        process.exit(1);
    });